# Getting Started

Contributions are welcome, and they are greatly appreciated! Every little bit helps,
and credit will always be given.

You can contribute in many ways.

## Types of Contributions

### Report bugs or request features

Report bugs and request new features in the repo [issue tracker][new-issue].
The issueforms will guide to include all necessary information, like package version,
Python version, operating system, and so on.

### Fix bugs or implement features

Look through the [GitHub issues][issues] for bugs and features. Anything tagged with
["bug" and "help wanted"][bug-help-wanted] is open to whoever wants to implement it.
Anything tagged with ["enhancement" and "help wanted"][feature-help-wanted] is open
to whoever wants to implement it.

### Write Documentation

Citric could always use more documentation, whether as part of the
official Citric docs, in docstrings, or even on the web in blog posts,
articles, and such.

If you're updating the Sphinx docs, you might want to check out [the docs guide][docs].

[bug-help-wanted]: https://github.com/edgarrmondragon/citric/issues?q=is%3Aopen+is%3Aissue+label%3Abug+label%3A%22help+wanted%22
[docs]: /contributing/docs
[feature-help-wanted]: https://github.com/edgarrmondragon/citric/issues?q=is%3Aopen+is%3Aissue+label%3Aenhancement+label%3A%22help+wanted%22
[issues]: https://github.com/edgarrmondragon/citric/issues
[new-issue]: https://github.com/edgarrmondragon/citric/issues/new/choose
